PushIdGenerator class

Utility class for generating Firebase child node keys.

Since the Flutter plugin API is asynchronous, there's no way for us to use the native SDK to generate the node key synchronously and we have to do it ourselves if we want to be able to reference the newly-created node synchronously.

This code is based on a Firebase blog post and ported to Dart. https://firebase.googleblog.com/2015/02/the-2120-ways-to-ensure-unique_68.html

Constructors

PushIdGenerator()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

generatePushChildName() String

Constants

PUSH_CHARS → const String